chrobot_extra/protocol/security

⚙️ This module was generated from the Chrome DevTools Protocol version 1.3

Security Domain

Security

📖 View this domain on the DevTools Protocol API Docs

Types

The action to take when a certificate error occurs. continue will continue processing the request and cancel will cancel the request.

pub type CertificateErrorAction {
  CertificateErrorActionContinue
  CertificateErrorActionCancel
}

Constructors

  • CertificateErrorActionContinue
  • CertificateErrorActionCancel

An internal certificate ID value.

pub type CertificateId {
  CertificateId(Int)
}

Constructors

  • CertificateId(Int)

A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories

pub type MixedContentType {
  MixedContentTypeBlockable
  MixedContentTypeOptionallyBlockable
  MixedContentTypeNone
}

Constructors

  • MixedContentTypeBlockable
  • MixedContentTypeOptionallyBlockable
  • MixedContentTypeNone

The security level of a page or resource.

pub type SecurityState {
  SecurityStateUnknown
  SecurityStateNeutral
  SecurityStateInsecure
  SecurityStateSecure
  SecurityStateInfo
  SecurityStateInsecureBroken
}

Constructors

  • SecurityStateUnknown
  • SecurityStateNeutral
  • SecurityStateInsecure
  • SecurityStateSecure
  • SecurityStateInfo
  • SecurityStateInsecureBroken

An explanation of an factor contributing to the security state.

pub type SecurityStateExplanation {
  SecurityStateExplanation(
    security_state: SecurityState,
    title: String,
    summary: String,
    description: String,
    mixed_content_type: MixedContentType,
    certificate: List(String),
    recommendations: option.Option(List(String)),
  )
}

Constructors

  • SecurityStateExplanation(
      security_state: SecurityState,
      title: String,
      summary: String,
      description: String,
      mixed_content_type: MixedContentType,
      certificate: List(String),
      recommendations: option.Option(List(String)),
    )

    Arguments

    security_state

    Security state representing the severity of the factor being explained.

    title

    Title describing the type of factor.

    summary

    Short phrase describing the type of factor.

    description

    Full text explanation of the factor.

    mixed_content_type

    The type of mixed content described by the explanation.

    certificate

    Page certificate.

    recommendations

    Recommendations to fix any issues.

Values

pub fn disable(
  callback__: fn(String, option.Option(a)) -> b,
) -> b

Disables tracking security state changes.

pub fn enable(callback__: fn(String, option.Option(a)) -> b) -> b

Enables tracking security state changes.

pub fn set_ignore_certificate_errors(
  callback__: fn(String, option.Option(json.Json)) -> a,
  ignore ignore: Bool,
) -> a

Enable/disable whether all certificate errors should be ignored.

Parameters:

  • ignore : If true, all certificate errors will be ignored.

Returns:

Search Document